# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/types/evidence.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/types/evidence.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftendermint/types/evidence.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto\"\xb2\x01\n\x08\x45vidence\x12J\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32\'.tendermint.types.DuplicateVoteEvidenceH\x00\x12S\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32+.tendermint.types.LightClientAttackEvidenceH\x00\x42\x05\n\x03sum\"\xd5\x01\n\x15\x44uplicateVoteEvidence\x12&\n\x06vote_a\x18\x01 \x01(\x0b\x32\x16.tendermint.types.Vote\x12&\n\x06vote_b\x18\x02 \x01(\x0b\x32\x16.tendermint.types.Vote\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\x12\x17\n\x0fvalidator_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"\xfb\x01\n\x19LightClientAttackEvidence\x12\x37\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1c.tendermint.types.LightBlock\x12\x15\n\rcommon_height\x18\x02 \x01(\x03\x12\x39\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1b.tendermint.types.Validator\x12\x1a\n\x12total_voting_power\x18\x04 \x01(\x03\x12\x37\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\"B\n\x0c\x45videnceList\x12\x32\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1a.tendermint.types.EvidenceB\x04\xc8\xde\x1f\x00\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=173
  _globals['_EVIDENCE']._serialized_end=351
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=354
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=567
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=570
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=821
  _globals['_EVIDENCELIST']._serialized_start=823
  _globals['_EVIDENCELIST']._serialized_end=889
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationResult(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    APPLICATION_RESULT_NOT_AVAILABLE: _ClassVar[ApplicationResult]
    APPLICATION_RESULT_ACCEPTED: _ClassVar[ApplicationResult]
    APPLICATION_RESULT_REJECTED: _ClassVar[ApplicationResult]
    APPLICATION_RESULT_RECLAIMED: _ClassVar[ApplicationResult]
APPLICATION_RESULT_NOT_AVAILABLE: ApplicationResult
APPLICATION_RESULT_ACCEPTED: ApplicationResult
APPLICATION_RESULT_REJECTED: ApplicationResult
APPLICATION_RESULT_RECLAIMED: ApplicationResult

class CreatorApplication(_message.Message):
    __slots__ = ("id", "creator", "result", "decision_timestamp", "decision_maker", "decision_reason", "stake", "description", "creation_timestamp")
    ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    DECISION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    DECISION_MAKER_FIELD_NUMBER: _ClassVar[int]
    DECISION_REASON_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATION_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    id: int
    creator: str
    result: ApplicationResult
    decision_timestamp: int
    decision_maker: str
    decision_reason: str
    stake: int
    description: str
    creation_timestamp: int
    def __init__(self, id: _Optional[int] = ..., creator: _Optional[str] = ..., result: _Optional[_Union[ApplicationResult, str]] = ..., decision_timestamp: _Optional[int] = ..., decision_maker: _Optional[str] = ..., decision_reason: _Optional[str] = ..., stake: _Optional[int] = ..., description: _Optional[str] = ..., creation_timestamp: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/pruning/v1/pruning.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/pruning/v1/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/pruning.proto\x12\x1c\x63ometbft.services.pruning.v1\"-\n\x1bSetBlockRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\x1e\n\x1cSetBlockRetainHeightResponse\"\x1d\n\x1bGetBlockRetainHeightRequest\"`\n\x1cGetBlockRetainHeightResponse\x12\x19\n\x11\x61pp_retain_height\x18\x01 \x01(\x04\x12%\n\x1dpruning_service_retain_height\x18\x02 \x01(\x04\"4\n\"SetBlockResultsRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"%\n#SetBlockResultsRetainHeightResponse\"$\n\"GetBlockResultsRetainHeightRequest\"L\n#GetBlockResultsRetainHeightResponse\x12%\n\x1dpruning_service_retain_height\x18\x01 \x01(\x04\"1\n\x1fSetTxIndexerRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"\"\n SetTxIndexerRetainHeightResponse\"!\n\x1fGetTxIndexerRetainHeightRequest\"2\n GetTxIndexerRetainHeightResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\"4\n\"SetBlockIndexerRetainHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\"%\n#SetBlockIndexerRetainHeightResponse\"$\n\"GetBlockIndexerRetainHeightRequest\"5\n#GetBlockIndexerRetainHeightResponse\x12\x0e\n\x06height\x18\x01 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_start=76
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_end=121
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=123
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=153
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_start=155
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_end=184
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=186
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=282
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=284
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=336
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=338
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=375
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=377
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=413
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=415
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=491
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=493
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=542
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=544
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=578
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=580
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=613
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=615
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=665
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=667
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=719
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=721
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=758
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=760
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=796
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=798
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=851
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.crucible.tx_pb2 import (
    MsgUpdateParams, MsgApplyCreator, MsgApproveApplication, MsgRejectApplication, MsgCreateTask,
    MsgRegisterTrainer, MsgRegisterScorer, MsgSubmitTrainingResult, MsgStakeToTask,
    MsgRequestScoringTask, MsgSubmitScore, MsgSubmitFinalResult, MsgReportModelPlagiarism,
    MsgAcceptPlagiarismReport, MsgRejectPlagiarismReport, MsgDisputeSubmissionScore,
    MsgStartTask, MsgAbortTask, MsgTriggerTaskToFinalSubmission, MsgTriggerTaskToFinalTesting,
    MsgTerminateTask, MsgClaimTaskReward, MsgUnstakeFromTask, MsgDisclaimCreatorStatus
)
from neurionpy.synapse.tx_helpers import SubmittedTx

from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.crucible.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse, QueryGetCreatorsRequest, QueryGetCreatorsResponse,
    QueryGetCreatorApplicationsRequest, QueryGetCreatorApplicationsResponse,
    QueryGetTaskRequest, QueryGetTaskResponse, QueryListAllTasksRequest, QueryListAllTasksResponse,
    QueryListTasksByStatusRequest, QueryListTasksByStatusResponse, QueryGetSubmissionRequest,
    QueryGetSubmissionResponse, QueryGetSubmissionByTaskCreatorRequest, QueryGetSubmissionByTaskCreatorResponse,
    QueryGetSubmissionByTaskRequest, QueryGetSubmissionByTaskResponse, QueryGetEncryptedProofOfOwnershipRequest,
    QueryGetEncryptedProofOfOwnershipResponse, QueryGetPlagiarismReportRequest, QueryGetPlagiarismReportResponse,
    QueryGetTaskRewardRequest, QueryGetTaskRewardResponse, QueryGetPendingCreatorApplicationsRequest,
    QueryGetPendingCreatorApplicationsResponse, QueryGetTaskStakeRequest, QueryGetTaskStakeResponse,
    QueryGetUnscoredSubmissionsByTaskRequest, QueryGetUnscoredSubmissionsByTaskResponse,
    QueryCanTriggerFinalSubmissionRequest, QueryCanTriggerFinalSubmissionResponse,
    QueryCanTriggerFinalTestingRequest, QueryCanTriggerFinalTestingResponse,
    QueryCanRegisterAsTrainerRequest, QueryCanRegisterAsTrainerResponse,
    QueryCanRegisterAsScorerRequest, QueryCanRegisterAsScorerResponse,
    QueryIsTrainerRequest, QueryIsTrainerResponse, QueryIsScorerRequest, QueryIsScorerResponse,
    QueryCanSubmitTrainingResultRequest, QueryCanSubmitTrainingResultResponse,
    QueryCanSubmitFinalResultRequest, QueryCanSubmitFinalResultResponse,
    QueryCanRequestScoringTaskRequest, QueryCanRequestScoringTaskResponse,
    QueryGetPendingScoringTasksRequest, QueryGetPendingScoringTasksResponse,
    QueryCanTerminateRequest, QueryCanTerminateResponse, QueryGetPlagiarismReportFromUserRequest,
    QueryGetPlagiarismReportFromUserResponse, QueryGetScoreDisputeFromUserRequest, QueryGetScoreDisputeFromUserResponse
)


class CrucibleQuery(ABC):
    """Crucible abstract class defining query methods."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """Query module parameters."""

    @abstractmethod
    def GetCreators(self, request: QueryGetCreatorsRequest) -> QueryGetCreatorsResponse:
        """Query the list of creators."""

    @abstractmethod
    def GetCreatorApplications(self, request: QueryGetCreatorApplicationsRequest) -> QueryGetCreatorApplicationsResponse:
        """Query creator applications for a given creator."""

    @abstractmethod
    def GetTask(self, request: QueryGetTaskRequest) -> QueryGetTaskResponse:
        """Query a task by its ID."""

    @abstractmethod
    def ListAllTasks(self, request: QueryListAllTasksRequest) -> QueryListAllTasksResponse:
        """Query all tasks with pagination."""

    @abstractmethod
    def ListTasksByStatus(self, request: QueryListTasksByStatusRequest) -> QueryListTasksByStatusResponse:
        """Query tasks by status with pagination."""

    @abstractmethod
    def GetSubmission(self, request: QueryGetSubmissionRequest) -> QueryGetSubmissionResponse:
        """Query a submission by its ID."""

    @abstractmethod
    def GetSubmissionByTask(self, request: QueryGetSubmissionByTaskRequest) -> QueryGetSubmissionByTaskResponse:
        """Query submissions by task ID."""

    @abstractmethod
    def GetSubmissionByTaskCreator(self, request: QueryGetSubmissionByTaskCreatorRequest) -> QueryGetSubmissionByTaskCreatorResponse:
        """Query a submission by task ID and creator."""

    @abstractmethod
    def GetEncryptedProofOfOwnership(self, request: QueryGetEncryptedProofOfOwnershipRequest) -> QueryGetEncryptedProofOfOwnershipResponse:
        """Query encrypted proof of ownership for a given key and plaintext."""

    @abstractmethod
    def GetPlagiarismReport(self, request: QueryGetPlagiarismReportRequest) -> QueryGetPlagiarismReportResponse:
        """Query a plagiarism report by report ID."""

    @abstractmethod
    def GetTaskReward(self, request: QueryGetTaskRewardRequest) -> QueryGetTaskRewardResponse:
        """Query task reward for a given task and user."""

    @abstractmethod
    def GetPendingCreatorApplications(self, request: QueryGetPendingCreatorApplicationsRequest) -> QueryGetPendingCreatorApplicationsResponse:
        """Query pending creator applications."""

    @abstractmethod
    def GetTaskStake(self, request: QueryGetTaskStakeRequest) -> QueryGetTaskStakeResponse:
        """Query task stake for a given task and user."""

    @abstractmethod
    def GetUnscoredSubmissionsByTask(self, request: QueryGetUnscoredSubmissionsByTaskRequest) -> QueryGetUnscoredSubmissionsByTaskResponse:
        """Query unscored submissions for a given task."""

    @abstractmethod
    def CanTriggerFinalSubmission(self, request: QueryCanTriggerFinalSubmissionRequest) -> QueryCanTriggerFinalSubmissionResponse:
        """Check if a user can trigger final submission for a task."""

    @abstractmethod
    def CanTriggerFinalTesting(self, request: QueryCanTriggerFinalTestingRequest) -> QueryCanTriggerFinalTestingResponse:
        """Check if a user can trigger final testing for a task."""

    @abstractmethod
    def CanRegisterAsTrainer(self, request: QueryCanRegisterAsTrainerRequest) -> QueryCanRegisterAsTrainerResponse:
        """Check if a user can register as a trainer."""

    @abstractmethod
    def CanRegisterAsScorer(self, request: QueryCanRegisterAsScorerRequest) -> QueryCanRegisterAsScorerResponse:
        """Check if a user can register as a scorer."""

    @abstractmethod
    def IsTrainer(self, request: QueryIsTrainerRequest) -> QueryIsTrainerResponse:
        """Check if a user is a trainer for a task."""

    @abstractmethod
    def IsScorer(self, request: QueryIsScorerRequest) -> QueryIsScorerResponse:
        """Check if a user is a scorer for a task."""

    @abstractmethod
    def CanSubmitTrainingResult(self, request: QueryCanSubmitTrainingResultRequest) -> QueryCanSubmitTrainingResultResponse:
        """Check if a user can submit a training result."""

    @abstractmethod
    def CanSubmitFinalResult(self, request: QueryCanSubmitFinalResultRequest) -> QueryCanSubmitFinalResultResponse:
        """Check if a user can submit the final result for a task."""

    @abstractmethod
    def CanRequestScoringTask(self, request: QueryCanRequestScoringTaskRequest) -> QueryCanRequestScoringTaskResponse:
        """Check if a user can request a scoring task."""

    @abstractmethod
    def GetPendingScoringTasks(self, request: QueryGetPendingScoringTasksRequest) -> QueryGetPendingScoringTasksResponse:
        """Query pending scoring tasks for a user and task."""

    @abstractmethod
    def CanTerminate(self, request: QueryCanTerminateRequest) -> QueryCanTerminateResponse:
        """Check if a task can be terminated by the creator."""

    @abstractmethod
    def GetPlagiarismReportFromUser(self, request: QueryGetPlagiarismReportFromUserRequest) -> QueryGetPlagiarismReportFromUserResponse:
        """Queries a list of plagiarism reports submitted by a specific user."""

    @abstractmethod
    def GetScoreDisputeFromUser(self, request: QueryGetScoreDisputeFromUserRequest) -> QueryGetScoreDisputeFromUserResponse:
        """Queries a list of score disputes raised by a specific user."""


class CrucibleMessage(ABC):
    """Crucible abstract class defining transaction messages."""

    @abstractmethod
    def UpdateParams(self, message: MsgUpdateParams, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Update module parameters."""

    @abstractmethod
    def ApplyCreator(self, message: MsgApplyCreator, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Apply to become a creator."""

    @abstractmethod
    def ApproveApplication(self, message: MsgApproveApplication, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Approve a creator application."""

    @abstractmethod
    def RejectApplication(self, message: MsgRejectApplication, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a creator application."""

    @abstractmethod
    def CreateTask(self, message: MsgCreateTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Create a new task."""

    @abstractmethod
    def RegisterTrainer(self, message: MsgRegisterTrainer, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register as a trainer for a task."""

    @abstractmethod
    def RegisterScorer(self, message: MsgRegisterScorer, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register as a scorer for a task."""

    @abstractmethod
    def SubmitTrainingResult(self, message: MsgSubmitTrainingResult, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Submit a training result for a task."""

    @abstractmethod
    def StakeToTask(self, message: MsgStakeToTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Stake tokens to a task."""

    @abstractmethod
    def RequestScoringTask(self, message: MsgRequestScoringTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Request scoring for a task."""

    @abstractmethod
    def SubmitScore(self, message: MsgSubmitScore, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Submit a score for a scoring task."""

    @abstractmethod
    def SubmitFinalResult(self, message: MsgSubmitFinalResult, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Submit the final result for a task."""

    @abstractmethod
    def ReportModelPlagiarism(self, message: MsgReportModelPlagiarism, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Report model plagiarism."""

    @abstractmethod
    def AcceptPlagiarismReport(self, message: MsgAcceptPlagiarismReport, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Accept a plagiarism report."""

    @abstractmethod
    def RejectPlagiarismReport(self, message: MsgRejectPlagiarismReport, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a plagiarism report."""

    @abstractmethod
    def DisputeSubmissionScore(self, message: MsgDisputeSubmissionScore, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Dispute a submission score."""

    @abstractmethod
    def StartTask(self, message: MsgStartTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Start a task."""

    @abstractmethod
    def AbortTask(self, message: MsgAbortTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Abort a task."""

    @abstractmethod
    def TriggerTaskToFinalSubmission(self, message: MsgTriggerTaskToFinalSubmission, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Trigger task transition to final submission phase."""

    @abstractmethod
    def TriggerTaskToFinalTesting(self, message: MsgTriggerTaskToFinalTesting, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Trigger task transition to final testing phase."""

    @abstractmethod
    def TerminateTask(self, message: MsgTerminateTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Terminate a task."""

    @abstractmethod
    def ClaimTaskReward(self, message: MsgClaimTaskReward, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Claim reward for a task."""

    @abstractmethod
    def UnstakeFromTask(self, message: MsgUnstakeFromTask, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Unstake tokens from a task."""

    @abstractmethod
    def DisclaimCreatorStatus(self, message: MsgDisclaimCreatorStatus, memo: Optional[str] = None, gas_limit: Optional[int] = None) -> SubmittedTx:
        """Disclaim creator status."""


from ibc.core.client.v1 import client_pb2 as _client_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("clients", "clients_consensus", "clients_metadata", "params", "create_localhost", "next_client_sequence")
    CLIENTS_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    CLIENTS_METADATA_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    CREATE_LOCALHOST_FIELD_NUMBER: _ClassVar[int]
    NEXT_CLIENT_SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    clients: _containers.RepeatedCompositeFieldContainer[_client_pb2.IdentifiedClientState]
    clients_consensus: _containers.RepeatedCompositeFieldContainer[_client_pb2.ClientConsensusStates]
    clients_metadata: _containers.RepeatedCompositeFieldContainer[IdentifiedGenesisMetadata]
    params: _client_pb2.Params
    create_localhost: bool
    next_client_sequence: int
    def __init__(self, clients: _Optional[_Iterable[_Union[_client_pb2.IdentifiedClientState, _Mapping]]] = ..., clients_consensus: _Optional[_Iterable[_Union[_client_pb2.ClientConsensusStates, _Mapping]]] = ..., clients_metadata: _Optional[_Iterable[_Union[IdentifiedGenesisMetadata, _Mapping]]] = ..., params: _Optional[_Union[_client_pb2.Params, _Mapping]] = ..., create_localhost: bool = ..., next_client_sequence: _Optional[int] = ...) -> None: ...

class GenesisMetadata(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ...) -> None: ...

class IdentifiedGenesisMetadata(_message.Message):
    __slots__ = ("client_id", "client_metadata")
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_METADATA_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_metadata: _containers.RepeatedCompositeFieldContainer[GenesisMetadata]
    def __init__(self, client_id: _Optional[str] = ..., client_metadata: _Optional[_Iterable[_Union[GenesisMetadata, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/app/v1alpha1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/app/v1alpha1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import config_pb2 as cosmos_dot_app_dot_v1alpha1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/app/v1alpha1/query.proto\x12\x13\x63osmos.app.v1alpha1\x1a cosmos/app/v1alpha1/config.proto\"\x14\n\x12QueryConfigRequest\"B\n\x13QueryConfigResponse\x12+\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1b.cosmos.app.v1alpha1.Config2i\n\x05Query\x12`\n\x06\x43onfig\x12\'.cosmos.app.v1alpha1.QueryConfigRequest\x1a(.cosmos.app.v1alpha1.QueryConfigResponse\"\x03\x88\x02\x01\x42+Z)cosmossdk.io/depinject/appconfig/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.v1alpha1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)cosmossdk.io/depinject/appconfig/v1alpha1'
  _globals['_QUERY'].methods_by_name['Config']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Config']._serialized_options = b'\210\002\001'
  _globals['_QUERYCONFIGREQUEST']._serialized_start=90
  _globals['_QUERYCONFIGREQUEST']._serialized_end=110
  _globals['_QUERYCONFIGRESPONSE']._serialized_start=112
  _globals['_QUERYCONFIGRESPONSE']._serialized_end=178
  _globals['_QUERY']._serialized_start=180
  _globals['_QUERY']._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/crucible/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/crucible/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from amino import amino_pb2 as amino_dot_amino__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from neurion.crucible import params_pb2 as neurion_dot_crucible_dot_params__pb2
from neurion.crucible import task_pb2 as neurion_dot_crucible_dot_task__pb2
from neurion.crucible import submission_pb2 as neurion_dot_crucible_dot_submission__pb2
from neurion.crucible import score_task_pb2 as neurion_dot_crucible_dot_score__task__pb2
from neurion.crucible import plagiarism_report_pb2 as neurion_dot_crucible_dot_plagiarism__report__pb2
from neurion.crucible import dispute_score_task_pb2 as neurion_dot_crucible_dot_dispute__score__task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19neurion/crucible/tx.proto\x12\x10neurion.crucible\x1a\x11\x61mino/amino.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1dneurion/crucible/params.proto\x1a\x1bneurion/crucible/task.proto\x1a!neurion/crucible/submission.proto\x1a!neurion/crucible/score_task.proto\x1a(neurion/crucible/plagiarism_report.proto\x1a)neurion/crucible/dispute_score_task.proto\"\xaa\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x33\n\x06params\x18\x02 \x01(\x0b\x32\x18.neurion.crucible.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:5\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\"neurion/x/crucible/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"E\n\x0fMsgApplyCreator\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x19\n\x17MsgApplyCreatorResponse\"^\n\x15MsgApproveApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1f\n\x1dMsgApproveApplicationResponse\"]\n\x14MsgRejectApplication\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgRejectApplicationResponse\"\xa9\x01\n\rMsgCreateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reward\x18\x02 \x01(\x04\x12\x14\n\x0ctraining_kit\x18\x03 \x01(\t\x12\x16\n\x0evalidation_kit\x18\x04 \x01(\t\x12\x18\n\x10\x64uration_in_days\x18\x05 \x01(\x04\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"H\n\x15MsgCreateTaskResponse\x12/\n\x04task\x18\x01 \x01(\x0b\x32\x16.neurion.crucible.TaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"S\n\x12MsgRegisterTrainer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgRegisterTrainerResponse\"R\n\x11MsgRegisterScorer\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\r\n\x05stake\x18\x02 \x01(\x04\x12\x0f\n\x07task_id\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1b\n\x19MsgRegisterScorerResponse\"\x91\x01\n\x17MsgSubmitTrainingResult\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12$\n\x1c\x65ncrypted_proof_of_ownership\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"^\n\x1fMsgSubmitTrainingResultResponse\x12;\n\nsubmission\x18\x01 \x01(\x0b\x32\x1c.neurion.crucible.SubmissionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"P\n\x0eMsgStakeToTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x18\n\x16MsgStakeToTaskResponse\"G\n\x15MsgRequestScoringTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"[\n\x1dMsgRequestScoringTaskResponse\x12:\n\nscore_task\x18\x01 \x01(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"U\n\x0eMsgSubmitScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x15\n\rscore_task_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"T\n\x16MsgSubmitScoreResponse\x12:\n\nscore_task\x18\x01 \x01(\x0b\x32\x1b.neurion.crucible.ScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x8e\x01\n\x14MsgSubmitFinalResult\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x10\n\x08metainfo\x18\x04 \x01(\t\x12$\n\x1c\x65ncrypted_proof_of_ownership\x18\x05 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1e\n\x1cMsgSubmitFinalResultResponse\"\x89\x01\n\x18MsgReportModelPlagiarism\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x18\n\x10my_submission_id\x18\x02 \x01(\x04\x12\x1f\n\x17suspected_submission_id\x18\x03 \x01(\x04\x12\x13\n\x0b\x65ncrypt_key\x18\x04 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"a\n MsgReportModelPlagiarismResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"j\n\x19MsgAcceptPlagiarismReport\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\treport_id\x18\x02 \x01(\x04\x12\x1b\n\x13proof_of_plagiarism\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n!MsgAcceptPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"]\n\x19MsgRejectPlagiarismReport\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x11\n\treport_id\x18\x02 \x01(\x04\x12\x0e\n\x06reason\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"b\n!MsgRejectPlagiarismReportResponse\x12=\n\x06report\x18\x01 \x01(\x0b\x32\".neurion.crucible.PlagiarismReportB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"`\n\x19MsgDisputeSubmissionScore\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\x04\x12\r\n\x05score\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"n\n!MsgDisputeSubmissionScoreResponse\x12I\n\x12\x64ispute_score_task\x18\x01 \x01(\x0b\x32\".neurion.crucible.DisputeScoreTaskB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\">\n\x0cMsgStartTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgStartTaskResponse\">\n\x0cMsgAbortTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x16\n\x14MsgAbortTaskResponse\"Q\n\x1fMsgTriggerTaskToFinalSubmission\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\")\n\'MsgTriggerTaskToFinalSubmissionResponse\"`\n\x1cMsgTriggerTaskToFinalTesting\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04\x12\x10\n\x08test_kit\x18\x03 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"&\n$MsgTriggerTaskToFinalTestingResponse\"B\n\x10MsgTerminateTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1a\n\x18MsgTerminateTaskResponse\"D\n\x12MsgClaimTaskReward\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgClaimTaskRewardResponse\"D\n\x12MsgUnstakeFromTask\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\x04:\x0c\x82\xe7\xb0*\x07\x63reator\"\x1c\n\x1aMsgUnstakeFromTaskResponse\"I\n\x18MsgDisclaimCreatorStatus\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t:\x0c\x82\xe7\xb0*\x07\x63reator\"\"\n MsgDisclaimCreatorStatusResponse2\xa5\x14\n\x03Msg\x12\\\n\x0cUpdateParams\x12!.neurion.crucible.MsgUpdateParams\x1a).neurion.crucible.MsgUpdateParamsResponse\x12\\\n\x0c\x41pplyCreator\x12!.neurion.crucible.MsgApplyCreator\x1a).neurion.crucible.MsgApplyCreatorResponse\x12n\n\x12\x41pproveApplication\x12\'.neurion.crucible.MsgApproveApplication\x1a/.neurion.crucible.MsgApproveApplicationResponse\x12k\n\x11RejectApplication\x12&.neurion.crucible.MsgRejectApplication\x1a..neurion.crucible.MsgRejectApplicationResponse\x12V\n\nCreateTask\x12\x1f.neurion.crucible.MsgCreateTask\x1a\'.neurion.crucible.MsgCreateTaskResponse\x12\x65\n\x0fRegisterTrainer\x12$.neurion.crucible.MsgRegisterTrainer\x1a,.neurion.crucible.MsgRegisterTrainerResponse\x12\x62\n\x0eRegisterScorer\x12#.neurion.crucible.MsgRegisterScorer\x1a+.neurion.crucible.MsgRegisterScorerResponse\x12t\n\x14SubmitTrainingResult\x12).neurion.crucible.MsgSubmitTrainingResult\x1a\x31.neurion.crucible.MsgSubmitTrainingResultResponse\x12Y\n\x0bStakeToTask\x12 .neurion.crucible.MsgStakeToTask\x1a(.neurion.crucible.MsgStakeToTaskResponse\x12n\n\x12RequestScoringTask\x12\'.neurion.crucible.MsgRequestScoringTask\x1a/.neurion.crucible.MsgRequestScoringTaskResponse\x12Y\n\x0bSubmitScore\x12 .neurion.crucible.MsgSubmitScore\x1a(.neurion.crucible.MsgSubmitScoreResponse\x12k\n\x11SubmitFinalResult\x12&.neurion.crucible.MsgSubmitFinalResult\x1a..neurion.crucible.MsgSubmitFinalResultResponse\x12w\n\x15ReportModelPlagiarism\x12*.neurion.crucible.MsgReportModelPlagiarism\x1a\x32.neurion.crucible.MsgReportModelPlagiarismResponse\x12z\n\x16\x41\x63\x63\x65ptPlagiarismReport\x12+.neurion.crucible.MsgAcceptPlagiarismReport\x1a\x33.neurion.crucible.MsgAcceptPlagiarismReportResponse\x12z\n\x16RejectPlagiarismReport\x12+.neurion.crucible.MsgRejectPlagiarismReport\x1a\x33.neurion.crucible.MsgRejectPlagiarismReportResponse\x12z\n\x16\x44isputeSubmissionScore\x12+.neurion.crucible.MsgDisputeSubmissionScore\x1a\x33.neurion.crucible.MsgDisputeSubmissionScoreResponse\x12S\n\tStartTask\x12\x1e.neurion.crucible.MsgStartTask\x1a&.neurion.crucible.MsgStartTaskResponse\x12S\n\tAbortTask\x12\x1e.neurion.crucible.MsgAbortTask\x1a&.neurion.crucible.MsgAbortTaskResponse\x12\x8c\x01\n\x1cTriggerTaskToFinalSubmission\x12\x31.neurion.crucible.MsgTriggerTaskToFinalSubmission\x1a\x39.neurion.crucible.MsgTriggerTaskToFinalSubmissionResponse\x12\x83\x01\n\x19TriggerTaskToFinalTesting\x12..neurion.crucible.MsgTriggerTaskToFinalTesting\x1a\x36.neurion.crucible.MsgTriggerTaskToFinalTestingResponse\x12_\n\rTerminateTask\x12\".neurion.crucible.MsgTerminateTask\x1a*.neurion.crucible.MsgTerminateTaskResponse\x12\x65\n\x0f\x43laimTaskReward\x12$.neurion.crucible.MsgClaimTaskReward\x1a,.neurion.crucible.MsgClaimTaskRewardResponse\x12\x65\n\x0fUnstakeFromTask\x12$.neurion.crucible.MsgUnstakeFromTask\x1a,.neurion.crucible.MsgUnstakeFromTaskResponse\x12w\n\x15\x44isclaimCreatorStatus\x12*.neurion.crucible.MsgDisclaimCreatorStatus\x1a\x32.neurion.crucible.MsgDisclaimCreatorStatusResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x1aZ\x18neurion/x/crucible/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.crucible.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/crucible/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\"neurion/x/crucible/MsgUpdateParams'
  _globals['_MSGAPPLYCREATOR']._loaded_options = None
  _globals['_MSGAPPLYCREATOR']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGAPPROVEAPPLICATION']._loaded_options = None
  _globals['_MSGAPPROVEAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTAPPLICATION']._loaded_options = None
  _globals['_MSGREJECTAPPLICATION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASK']._loaded_options = None
  _globals['_MSGCREATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._loaded_options = None
  _globals['_MSGCREATETASKRESPONSE'].fields_by_name['task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREGISTERTRAINER']._loaded_options = None
  _globals['_MSGREGISTERTRAINER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREGISTERSCORER']._loaded_options = None
  _globals['_MSGREGISTERSCORER']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITTRAININGRESULT']._loaded_options = None
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE'].fields_by_name['submission']._loaded_options = None
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE'].fields_by_name['submission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTAKETOTASK']._loaded_options = None
  _globals['_MSGSTAKETOTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTSCORINGTASK']._loaded_options = None
  _globals['_MSGREQUESTSCORINGTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREQUESTSCORINGTASKRESPONSE'].fields_by_name['score_task']._loaded_options = None
  _globals['_MSGREQUESTSCORINGTASKRESPONSE'].fields_by_name['score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSUBMITSCORE']._loaded_options = None
  _globals['_MSGSUBMITSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGSUBMITSCORERESPONSE'].fields_by_name['score_task']._loaded_options = None
  _globals['_MSGSUBMITSCORERESPONSE'].fields_by_name['score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSUBMITFINALRESULT']._loaded_options = None
  _globals['_MSGSUBMITFINALRESULT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTMODELPLAGIARISM']._loaded_options = None
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGACCEPTPLAGIARISMREPORT']._loaded_options = None
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGREJECTPLAGIARISMREPORT']._loaded_options = None
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._loaded_options = None
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE'].fields_by_name['report']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGDISPUTESUBMISSIONSCORE']._loaded_options = None
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE'].fields_by_name['dispute_score_task']._loaded_options = None
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE'].fields_by_name['dispute_score_task']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGSTARTTASK']._loaded_options = None
  _globals['_MSGSTARTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGABORTTASK']._loaded_options = None
  _globals['_MSGABORTTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._loaded_options = None
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._loaded_options = None
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGTERMINATETASK']._loaded_options = None
  _globals['_MSGTERMINATETASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGCLAIMTASKREWARD']._loaded_options = None
  _globals['_MSGCLAIMTASKREWARD']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGUNSTAKEFROMTASK']._loaded_options = None
  _globals['_MSGUNSTAKEFROMTASK']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSGDISCLAIMCREATORSTATUS']._loaded_options = None
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_options = b'\202\347\260*\007creator'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=356
  _globals['_MSGUPDATEPARAMS']._serialized_end=526
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=528
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=553
  _globals['_MSGAPPLYCREATOR']._serialized_start=555
  _globals['_MSGAPPLYCREATOR']._serialized_end=624
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_start=626
  _globals['_MSGAPPLYCREATORRESPONSE']._serialized_end=651
  _globals['_MSGAPPROVEAPPLICATION']._serialized_start=653
  _globals['_MSGAPPROVEAPPLICATION']._serialized_end=747
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_start=749
  _globals['_MSGAPPROVEAPPLICATIONRESPONSE']._serialized_end=780
  _globals['_MSGREJECTAPPLICATION']._serialized_start=782
  _globals['_MSGREJECTAPPLICATION']._serialized_end=875
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_start=877
  _globals['_MSGREJECTAPPLICATIONRESPONSE']._serialized_end=907
  _globals['_MSGCREATETASK']._serialized_start=910
  _globals['_MSGCREATETASK']._serialized_end=1079
  _globals['_MSGCREATETASKRESPONSE']._serialized_start=1081
  _globals['_MSGCREATETASKRESPONSE']._serialized_end=1153
  _globals['_MSGREGISTERTRAINER']._serialized_start=1155
  _globals['_MSGREGISTERTRAINER']._serialized_end=1238
  _globals['_MSGREGISTERTRAINERRESPONSE']._serialized_start=1240
  _globals['_MSGREGISTERTRAINERRESPONSE']._serialized_end=1268
  _globals['_MSGREGISTERSCORER']._serialized_start=1270
  _globals['_MSGREGISTERSCORER']._serialized_end=1352
  _globals['_MSGREGISTERSCORERRESPONSE']._serialized_start=1354
  _globals['_MSGREGISTERSCORERRESPONSE']._serialized_end=1381
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_start=1384
  _globals['_MSGSUBMITTRAININGRESULT']._serialized_end=1529
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE']._serialized_start=1531
  _globals['_MSGSUBMITTRAININGRESULTRESPONSE']._serialized_end=1625
  _globals['_MSGSTAKETOTASK']._serialized_start=1627
  _globals['_MSGSTAKETOTASK']._serialized_end=1707
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_start=1709
  _globals['_MSGSTAKETOTASKRESPONSE']._serialized_end=1733
  _globals['_MSGREQUESTSCORINGTASK']._serialized_start=1735
  _globals['_MSGREQUESTSCORINGTASK']._serialized_end=1806
  _globals['_MSGREQUESTSCORINGTASKRESPONSE']._serialized_start=1808
  _globals['_MSGREQUESTSCORINGTASKRESPONSE']._serialized_end=1899
  _globals['_MSGSUBMITSCORE']._serialized_start=1901
  _globals['_MSGSUBMITSCORE']._serialized_end=1986
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_start=1988
  _globals['_MSGSUBMITSCORERESPONSE']._serialized_end=2072
  _globals['_MSGSUBMITFINALRESULT']._serialized_start=2075
  _globals['_MSGSUBMITFINALRESULT']._serialized_end=2217
  _globals['_MSGSUBMITFINALRESULTRESPONSE']._serialized_start=2219
  _globals['_MSGSUBMITFINALRESULTRESPONSE']._serialized_end=2249
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_start=2252
  _globals['_MSGREPORTMODELPLAGIARISM']._serialized_end=2389
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE']._serialized_start=2391
  _globals['_MSGREPORTMODELPLAGIARISMRESPONSE']._serialized_end=2488
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_start=2490
  _globals['_MSGACCEPTPLAGIARISMREPORT']._serialized_end=2596
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE']._serialized_start=2598
  _globals['_MSGACCEPTPLAGIARISMREPORTRESPONSE']._serialized_end=2696
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_start=2698
  _globals['_MSGREJECTPLAGIARISMREPORT']._serialized_end=2791
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE']._serialized_start=2793
  _globals['_MSGREJECTPLAGIARISMREPORTRESPONSE']._serialized_end=2891
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_start=2893
  _globals['_MSGDISPUTESUBMISSIONSCORE']._serialized_end=2989
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE']._serialized_start=2991
  _globals['_MSGDISPUTESUBMISSIONSCORERESPONSE']._serialized_end=3101
  _globals['_MSGSTARTTASK']._serialized_start=3103
  _globals['_MSGSTARTTASK']._serialized_end=3165
  _globals['_MSGSTARTTASKRESPONSE']._serialized_start=3167
  _globals['_MSGSTARTTASKRESPONSE']._serialized_end=3189
  _globals['_MSGABORTTASK']._serialized_start=3191
  _globals['_MSGABORTTASK']._serialized_end=3253
  _globals['_MSGABORTTASKRESPONSE']._serialized_start=3255
  _globals['_MSGABORTTASKRESPONSE']._serialized_end=3277
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_start=3279
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSION']._serialized_end=3360
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSIONRESPONSE']._serialized_start=3362
  _globals['_MSGTRIGGERTASKTOFINALSUBMISSIONRESPONSE']._serialized_end=3403
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_start=3405
  _globals['_MSGTRIGGERTASKTOFINALTESTING']._serialized_end=3501
  _globals['_MSGTRIGGERTASKTOFINALTESTINGRESPONSE']._serialized_start=3503
  _globals['_MSGTRIGGERTASKTOFINALTESTINGRESPONSE']._serialized_end=3541
  _globals['_MSGTERMINATETASK']._serialized_start=3543
  _globals['_MSGTERMINATETASK']._serialized_end=3609
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_start=3611
  _globals['_MSGTERMINATETASKRESPONSE']._serialized_end=3637
  _globals['_MSGCLAIMTASKREWARD']._serialized_start=3639
  _globals['_MSGCLAIMTASKREWARD']._serialized_end=3707
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_start=3709
  _globals['_MSGCLAIMTASKREWARDRESPONSE']._serialized_end=3737
  _globals['_MSGUNSTAKEFROMTASK']._serialized_start=3739
  _globals['_MSGUNSTAKEFROMTASK']._serialized_end=3807
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_start=3809
  _globals['_MSGUNSTAKEFROMTASKRESPONSE']._serialized_end=3837
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_start=3839
  _globals['_MSGDISCLAIMCREATORSTATUS']._serialized_end=3912
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_start=3914
  _globals['_MSGDISCLAIMCREATORSTATUSRESPONSE']._serialized_end=3948
  _globals['_MSG']._serialized_start=3951
  _globals['_MSG']._serialized_end=6548
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/abci/v2/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/abci/v2/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.crypto.v1 import proof_pb2 as cometbft_dot_crypto_dot_v1_dot_proof__pb2
from cometbft.types.v2 import params_pb2 as cometbft_dot_types_dot_v2_dot_params__pb2
from cometbft.types.v2 import validator_pb2 as cometbft_dot_types_dot_v2_dot_validator__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63ometbft/abci/v2/types.proto\x12\x10\x63ometbft.abci.v2\x1a\x1e\x63ometbft/crypto/v1/proof.proto\x1a\x1e\x63ometbft/types/v2/params.proto\x1a!cometbft/types/v2/validator.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\x82\x08\n\x07Request\x12-\n\x04\x65\x63ho\x18\x01 \x01(\x0b\x32\x1d.cometbft.abci.v2.EchoRequestH\x00\x12/\n\x05\x66lush\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v2.FlushRequestH\x00\x12-\n\x04info\x18\x03 \x01(\x0b\x32\x1d.cometbft.abci.v2.InfoRequestH\x00\x12\x38\n\ninit_chain\x18\x05 \x01(\x0b\x32\".cometbft.abci.v2.InitChainRequestH\x00\x12/\n\x05query\x18\x06 \x01(\x0b\x32\x1e.cometbft.abci.v2.QueryRequestH\x00\x12\x34\n\x08\x63heck_tx\x18\x08 \x01(\x0b\x32 .cometbft.abci.v2.CheckTxRequestH\x00\x12\x31\n\x06\x63ommit\x18\x0b \x01(\x0b\x32\x1f.cometbft.abci.v2.CommitRequestH\x00\x12@\n\x0elist_snapshots\x18\x0c \x01(\x0b\x32&.cometbft.abci.v2.ListSnapshotsRequestH\x00\x12@\n\x0eoffer_snapshot\x18\r \x01(\x0b\x32&.cometbft.abci.v2.OfferSnapshotRequestH\x00\x12I\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b\x32*.cometbft.abci.v2.LoadSnapshotChunkRequestH\x00\x12K\n\x14\x61pply_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v2.ApplySnapshotChunkRequestH\x00\x12\x44\n\x10prepare_proposal\x18\x10 \x01(\x0b\x32(.cometbft.abci.v2.PrepareProposalRequestH\x00\x12\x44\n\x10process_proposal\x18\x11 \x01(\x0b\x32(.cometbft.abci.v2.ProcessProposalRequestH\x00\x12:\n\x0b\x65xtend_vote\x18\x12 \x01(\x0b\x32#.cometbft.abci.v2.ExtendVoteRequestH\x00\x12M\n\x15verify_vote_extension\x18\x13 \x01(\x0b\x32,.cometbft.abci.v2.VerifyVoteExtensionRequestH\x00\x12@\n\x0e\x66inalize_block\x18\x14 \x01(\x0b\x32&.cometbft.abci.v2.FinalizeBlockRequestH\x00\x42\x07\n\x05valueJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"\x1e\n\x0b\x45\x63hoRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0c\x46lushRequest\"`\n\x0bInfoRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\x12\x14\n\x0c\x61\x62\x63i_version\x18\x04 \x01(\t\"\x84\x02\n\x10InitChainRequest\x12\x32\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12<\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12;\n\nvalidators\x18\x04 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03\"I\n\x0cQueryRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"O\n\x0e\x43heckTxRequest\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12+\n\x04type\x18\x03 \x01(\x0e\x32\x1d.cometbft.abci.v2.CheckTxTypeJ\x04\x08\x02\x10\x03\"\x0f\n\rCommitRequest\"\x16\n\x14ListSnapshotsRequest\"V\n\x14OfferSnapshotRequest\x12,\n\x08snapshot\x18\x01 \x01(\x0b\x32\x1a.cometbft.abci.v2.Snapshot\x12\x10\n\x08\x61pp_hash\x18\x02 \x01(\x0c\"I\n\x18LoadSnapshotChunkRequest\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\r\n\x05\x63hunk\x18\x03 \x01(\r\"I\n\x19\x41pplySnapshotChunkRequest\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t\"\xb8\x02\n\x16PrepareProposalRequest\x12\x14\n\x0cmax_tx_bytes\x18\x01 \x01(\x03\x12\x0b\n\x03txs\x18\x02 \x03(\x0c\x12\x45\n\x11local_last_commit\x18\x03 \x01(\x0b\x32$.cometbft.abci.v2.ExtendedCommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x04 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xab\x02\n\x16ProcessProposalRequest\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12@\n\x14proposed_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\xa6\x02\n\x11\x45xtendVoteRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\x32\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x0b\n\x03txs\x18\x04 \x03(\x0c\x12@\n\x14proposed_last_commit\x18\x05 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x06 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\"\x8c\x01\n\x1aVerifyVoteExtensionRequest\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x16\n\x0evote_extension\x18\x04 \x01(\x0c\x12\x1d\n\x15non_rp_vote_extension\x18\x05 \x01(\x0c\"\xc3\x02\n\x14\x46inalizeBlockRequest\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\x12?\n\x13\x64\x65\x63ided_last_commit\x18\x02 \x01(\x0b\x32\x1c.cometbft.abci.v2.CommitInfoB\x04\xc8\xde\x1f\x00\x12\x38\n\x0bmisbehavior\x18\x03 \x03(\x0b\x32\x1d.cometbft.abci.v2.MisbehaviorB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x0e\n\x06height\x18\x05 \x01(\x03\x12\x32\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1c\n\x14next_validators_hash\x18\x07 \x01(\x0c\x12\x18\n\x10proposer_address\x18\x08 \x01(\x0c\x12\x19\n\x11syncing_to_height\x18\t \x01(\x03\"\xcd\x08\n\x08Response\x12\x38\n\texception\x18\x01 \x01(\x0b\x32#.cometbft.abci.v2.ExceptionResponseH\x00\x12.\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x1e.cometbft.abci.v2.EchoResponseH\x00\x12\x30\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1f.cometbft.abci.v2.FlushResponseH\x00\x12.\n\x04info\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v2.InfoResponseH\x00\x12\x39\n\ninit_chain\x18\x06 \x01(\x0b\x32#.cometbft.abci.v2.InitChainResponseH\x00\x12\x30\n\x05query\x18\x07 \x01(\x0b\x32\x1f.cometbft.abci.v2.QueryResponseH\x00\x12\x35\n\x08\x63heck_tx\x18\t \x01(\x0b\x32!.cometbft.abci.v2.CheckTxResponseH\x00\x12\x32\n\x06\x63ommit\x18\x0c \x01(\x0b\x32 .cometbft.abci.v2.CommitResponseH\x00\x12\x41\n\x0elist_snapshots\x18\r \x01(\x0b\x32\'.cometbft.abci.v2.ListSnapshotsResponseH\x00\x12\x41\n\x0eoffer_snapshot\x18\x0e \x01(\x0b\x32\'.cometbft.abci.v2.OfferSnapshotResponseH\x00\x12J\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b\x32+.cometbft.abci.v2.LoadSnapshotChunkResponseH\x00\x12L\n\x14\x61pply_snapshot_chunk\x18\x10 \x01(\x0b\x32,.cometbft.abci.v2.ApplySnapshotChunkResponseH\x00\x12\x45\n\x10prepare_proposal\x18\x11 \x01(\x0b\x32).cometbft.abci.v2.PrepareProposalResponseH\x00\x12\x45\n\x10process_proposal\x18\x12 \x01(\x0b\x32).cometbft.abci.v2.ProcessProposalResponseH\x00\x12;\n\x0b\x65xtend_vote\x18\x13 \x01(\x0b\x32$.cometbft.abci.v2.ExtendVoteResponseH\x00\x12N\n\x15verify_vote_extension\x18\x14 \x01(\x0b\x32-.cometbft.abci.v2.VerifyVoteExtensionResponseH\x00\x12\x41\n\x0e\x66inalize_block\x18\x15 \x01(\x0b\x32\'.cometbft.abci.v2.FinalizeBlockResponseH\x00\x42\x07\n\x05valueJ\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"\"\n\x11\x45xceptionResponse\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0c\x45\x63hoResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rFlushResponse\"\x94\x02\n\x0cInfoResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\x12K\n\x0flane_priorities\x18\x06 \x03(\x0b\x32\x32.cometbft.abci.v2.InfoResponse.LanePrioritiesEntry\x12\x14\n\x0c\x64\x65\x66\x61ult_lane\x18\x07 \x01(\t\x1a\x35\n\x13LanePrioritiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\xa0\x01\n\x11InitChainResponse\x12<\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12;\n\nvalidators\x18\x02 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x61pp_hash\x18\x03 \x01(\x0c\"\xb7\x01\n\rQueryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12/\n\tproof_ops\x18\x08 \x01(\x0b\x32\x1c.cometbft.crypto.v1.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"\x92\x02\n\x0f\x43heckTxResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x41\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\x12\x0f\n\x07lane_id\x18\x0c \x01(\tJ\x04\x08\t\x10\x0cR\x06senderR\x08priorityR\rmempool_error\"3\n\x0e\x43ommitResponse\x12\x15\n\rretain_height\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"F\n\x15ListSnapshotsResponse\x12-\n\tsnapshots\x18\x01 \x03(\x0b\x32\x1a.cometbft.abci.v2.Snapshot\"N\n\x15OfferSnapshotResponse\x12\x35\n\x06result\x18\x01 \x01(\x0e\x32%.cometbft.abci.v2.OfferSnapshotResult\"*\n\x19LoadSnapshotChunkResponse\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\x88\x01\n\x1a\x41pplySnapshotChunkResponse\x12:\n\x06result\x18\x01 \x01(\x0e\x32*.cometbft.abci.v2.ApplySnapshotChunkResult\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t\"&\n\x17PrepareProposalResponse\x12\x0b\n\x03txs\x18\x01 \x03(\x0c\"R\n\x17ProcessProposalResponse\x12\x37\n\x06status\x18\x01 \x01(\x0e\x32\'.cometbft.abci.v2.ProcessProposalStatus\"F\n\x12\x45xtendVoteResponse\x12\x16\n\x0evote_extension\x18\x01 \x01(\x0c\x12\x18\n\x10non_rp_extension\x18\x02 \x01(\x0c\"Z\n\x1bVerifyVoteExtensionResponse\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.cometbft.abci.v2.VerifyVoteExtensionStatus\"\xe8\x02\n\x15\x46inalizeBlockResponse\x12\x41\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x32\n\ntx_results\x18\x02 \x03(\x0b\x32\x1e.cometbft.abci.v2.ExecTxResult\x12\x42\n\x11validator_updates\x18\x03 \x03(\x0b\x32!.cometbft.abci.v2.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x43\n\x17\x63onsensus_param_updates\x18\x04 \x01(\x0b\x32\".cometbft.types.v2.ConsensusParams\x12\x10\n\x08\x61pp_hash\x18\x05 \x01(\x0c\x12=\n\x10next_block_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\"L\n\nCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12/\n\x05votes\x18\x02 \x03(\x0b\x32\x1a.cometbft.abci.v2.VoteInfoB\x04\xc8\xde\x1f\x00\"\\\n\x12\x45xtendedCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12\x37\n\x05votes\x18\x02 \x03(\x0b\x32\".cometbft.abci.v2.ExtendedVoteInfoB\x04\xc8\xde\x1f\x00\"i\n\x05\x45vent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12R\n\nattributes\x18\x02 \x03(\x0b\x32 .cometbft.abci.v2.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14\x61ttributes,omitempty\";\n\x0e\x45ventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05index\x18\x03 \x01(\x08\"\xd7\x01\n\x0c\x45xecTxResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12\x41\n\x06\x65vents\x18\x07 \x03(\x0b\x32\x17.cometbft.abci.v2.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t\"k\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x12\x34\n\x06result\x18\x04 \x01(\x0b\x32\x1e.cometbft.abci.v2.ExecTxResultB\x04\xc8\xde\x1f\x00\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"S\n\x0fValidatorUpdate\x12\r\n\x05power\x18\x02 \x01(\x03\x12\x15\n\rpub_key_bytes\x18\x03 \x01(\x0c\x12\x14\n\x0cpub_key_type\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02\"}\n\x08VoteInfo\x12\x34\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x35\n\rblock_id_flag\x18\x03 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlagJ\x04\x08\x02\x10\x03\"\xfd\x01\n\x10\x45xtendedVoteInfo\x12\x34\n\tvalidator\x18\x01 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x16\n\x0evote_extension\x18\x03 \x01(\x0c\x12\x1b\n\x13\x65xtension_signature\x18\x04 \x01(\x0c\x12\x35\n\rblock_id_flag\x18\x05 \x01(\x0e\x32\x1e.cometbft.types.v2.BlockIDFlag\x12\x1d\n\x15non_rp_vote_extension\x18\x06 \x01(\x0c\x12\"\n\x1anon_rp_extension_signature\x18\x07 \x01(\x0cJ\x04\x08\x02\x10\x03\"\xd4\x01\n\x0bMisbehavior\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.cometbft.abci.v2.MisbehaviorType\x12\x34\n\tvalidator\x18\x02 \x01(\x0b\x32\x1b.cometbft.abci.v2.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x32\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\r\x12\x0e\n\x06\x63hunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*b\n\x0b\x43heckTxType\x12\x19\n\x15\x43HECK_TX_TYPE_UNKNOWN\x10\x00\x12\x19\n\x15\x43HECK_TX_TYPE_RECHECK\x10\x01\x12\x17\n\x13\x43HECK_TX_TYPE_CHECK\x10\x02\x1a\x04\x88\xa3\x1e\x00*\xf5\x01\n\x13OfferSnapshotResult\x12!\n\x1dOFFER_SNAPSHOT_RESULT_UNKNOWN\x10\x00\x12 \n\x1cOFFER_SNAPSHOT_RESULT_ACCEPT\x10\x01\x12\x1f\n\x1bOFFER_SNAPSHOT_RESULT_ABORT\x10\x02\x12 \n\x1cOFFER_SNAPSHOT_RESULT_REJECT\x10\x03\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_FORMAT\x10\x04\x12\'\n#OFFER_SNAPSHOT_RESULT_REJECT_SENDER\x10\x05\x1a\x04\x88\xa3\x1e\x00*\xa0\x02\n\x18\x41pplySnapshotChunkResult\x12\'\n#APPLY_SNAPSHOT_CHUNK_RESULT_UNKNOWN\x10\x00\x12&\n\"APPLY_SNAPSHOT_CHUNK_RESULT_ACCEPT\x10\x01\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_ABORT\x10\x02\x12%\n!APPLY_SNAPSHOT_CHUNK_RESULT_RETRY\x10\x03\x12.\n*APPLY_SNAPSHOT_CHUNK_RESULT_RETRY_SNAPSHOT\x10\x04\x12/\n+APPLY_SNAPSHOT_CHUNK_RESULT_REJECT_SNAPSHOT\x10\x05\x1a\x04\x88\xa3\x1e\x00*\x8a\x01\n\x15ProcessProposalStatus\x12#\n\x1fPROCESS_PROPOSAL_STATUS_UNKNOWN\x10\x00\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_ACCEPT\x10\x01\x12\"\n\x1ePROCESS_PROPOSAL_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x9d\x01\n\x19VerifyVoteExtensionStatus\x12(\n$VERIFY_VOTE_EXTENSION_STATUS_UNKNOWN\x10\x00\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_ACCEPT\x10\x01\x12\'\n#VERIFY_VOTE_EXTENSION_STATUS_REJECT\x10\x02\x1a\x04\x88\xa3\x1e\x00*\x84\x01\n\x0fMisbehaviorType\x12\x1c\n\x18MISBEHAVIOR_TYPE_UNKNOWN\x10\x00\x12#\n\x1fMISBEHAVIOR_TYPE_DUPLICATE_VOTE\x10\x01\x12(\n$MISBEHAVIOR_TYPE_LIGHT_CLIENT_ATTACK\x10\x02\x1a\x04\x88\xa3\x1e\x00\x42\x33Z1github.com/cometbft/cometbft/api/cometbft/abci/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.abci.v2.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cometbft/cometbft/api/cometbft/abci/v2'
  _globals['_CHECKTXTYPE']._loaded_options = None
  _globals['_CHECKTXTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_OFFERSNAPSHOTRESULT']._loaded_options = None
  _globals['_OFFERSNAPSHOTRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._loaded_options = None
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_options = b'\210\243\036\000'
  _globals['_PROCESSPROPOSALSTATUS']._loaded_options = None
  _globals['_PROCESSPROPOSALSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._loaded_options = None
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_MISBEHAVIORTYPE']._loaded_options = None
  _globals['_MISBEHAVIORTYPE']._serialized_options = b'\210\243\036\000'
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINREQUEST'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['local_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PREPAREPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_PROCESSPROPOSALREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['proposed_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_EXTENDVOTEREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['decided_last_commit']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['misbehavior']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._loaded_options = None
  _globals['_FINALIZEBLOCKREQUEST'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._loaded_options = None
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_options = b'8\001'
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_INITCHAINRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_CHECKTXRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['next_block_delay']._loaded_options = None
  _globals['_FINALIZEBLOCKRESPONSE'].fields_by_name['next_block_delay']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_COMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_COMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._loaded_options = None
  _globals['_EXTENDEDCOMMITINFO'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_EVENT'].fields_by_name['attributes']._loaded_options = None
  _globals['_EVENT'].fields_by_name['attributes']._serialized_options = b'\310\336\037\000\352\336\037\024attributes,omitempty'
  _globals['_EXECTXRESULT'].fields_by_name['events']._loaded_options = None
  _globals['_EXECTXRESULT'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_TXRESULT'].fields_by_name['result']._loaded_options = None
  _globals['_TXRESULT'].fields_by_name['result']._serialized_options = b'\310\336\037\000'
  _globals['_VOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_VOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._loaded_options = None
  _globals['_EXTENDEDVOTEINFO'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['validator']._serialized_options = b'\310\336\037\000'
  _globals['_MISBEHAVIOR'].fields_by_name['time']._loaded_options = None
  _globals['_MISBEHAVIOR'].fields_by_name['time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_CHECKTXTYPE']._serialized_start=8113
  _globals['_CHECKTXTYPE']._serialized_end=8211
  _globals['_OFFERSNAPSHOTRESULT']._serialized_start=8214
  _globals['_OFFERSNAPSHOTRESULT']._serialized_end=8459
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_start=8462
  _globals['_APPLYSNAPSHOTCHUNKRESULT']._serialized_end=8750
  _globals['_PROCESSPROPOSALSTATUS']._serialized_start=8753
  _globals['_PROCESSPROPOSALSTATUS']._serialized_end=8891
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_start=8894
  _globals['_VERIFYVOTEEXTENSIONSTATUS']._serialized_end=9051
  _globals['_MISBEHAVIORTYPE']._serialized_start=9054
  _globals['_MISBEHAVIORTYPE']._serialized_end=9186
  _globals['_REQUEST']._serialized_start=237
  _globals['_REQUEST']._serialized_end=1263
  _globals['_ECHOREQUEST']._serialized_start=1265
  _globals['_ECHOREQUEST']._serialized_end=1295
  _globals['_FLUSHREQUEST']._serialized_start=1297
  _globals['_FLUSHREQUEST']._serialized_end=1311
  _globals['_INFOREQUEST']._serialized_start=1313
  _globals['_INFOREQUEST']._serialized_end=1409
  _globals['_INITCHAINREQUEST']._serialized_start=1412
  _globals['_INITCHAINREQUEST']._serialized_end=1672
  _globals['_QUERYREQUEST']._serialized_start=1674
  _globals['_QUERYREQUEST']._serialized_end=1747
  _globals['_CHECKTXREQUEST']._serialized_start=1749
  _globals['_CHECKTXREQUEST']._serialized_end=1828
  _globals['_COMMITREQUEST']._serialized_start=1830
  _globals['_COMMITREQUEST']._serialized_end=1845
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_start=1847
  _globals['_LISTSNAPSHOTSREQUEST']._serialized_end=1869
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_start=1871
  _globals['_OFFERSNAPSHOTREQUEST']._serialized_end=1957
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_start=1959
  _globals['_LOADSNAPSHOTCHUNKREQUEST']._serialized_end=2032
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_start=2034
  _globals['_APPLYSNAPSHOTCHUNKREQUEST']._serialized_end=2107
  _globals['_PREPAREPROPOSALREQUEST']._serialized_start=2110
  _globals['_PREPAREPROPOSALREQUEST']._serialized_end=2422
  _globals['_PROCESSPROPOSALREQUEST']._serialized_start=2425
  _globals['_PROCESSPROPOSALREQUEST']._serialized_end=2724
  _globals['_EXTENDVOTEREQUEST']._serialized_start=2727
  _globals['_EXTENDVOTEREQUEST']._serialized_end=3021
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_start=3024
  _globals['_VERIFYVOTEEXTENSIONREQUEST']._serialized_end=3164
  _globals['_FINALIZEBLOCKREQUEST']._serialized_start=3167
  _globals['_FINALIZEBLOCKREQUEST']._serialized_end=3490
  _globals['_RESPONSE']._serialized_start=3493
  _globals['_RESPONSE']._serialized_end=4594
  _globals['_EXCEPTIONRESPONSE']._serialized_start=4596
  _globals['_EXCEPTIONRESPONSE']._serialized_end=4630
  _globals['_ECHORESPONSE']._serialized_start=4632
  _globals['_ECHORESPONSE']._serialized_end=4663
  _globals['_FLUSHRESPONSE']._serialized_start=4665
  _globals['_FLUSHRESPONSE']._serialized_end=4680
  _globals['_INFORESPONSE']._serialized_start=4683
  _globals['_INFORESPONSE']._serialized_end=4959
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_start=4906
  _globals['_INFORESPONSE_LANEPRIORITIESENTRY']._serialized_end=4959
  _globals['_INITCHAINRESPONSE']._serialized_start=4962
  _globals['_INITCHAINRESPONSE']._serialized_end=5122
  _globals['_QUERYRESPONSE']._serialized_start=5125
  _globals['_QUERYRESPONSE']._serialized_end=5308
  _globals['_CHECKTXRESPONSE']._serialized_start=5311
  _globals['_CHECKTXRESPONSE']._serialized_end=5585
  _globals['_COMMITRESPONSE']._serialized_start=5587
  _globals['_COMMITRESPONSE']._serialized_end=5638
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_start=5640
  _globals['_LISTSNAPSHOTSRESPONSE']._serialized_end=5710
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_start=5712
  _globals['_OFFERSNAPSHOTRESPONSE']._serialized_end=5790
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_start=5792
  _globals['_LOADSNAPSHOTCHUNKRESPONSE']._serialized_end=5834
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_start=5837
  _globals['_APPLYSNAPSHOTCHUNKRESPONSE']._serialized_end=5973
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_start=5975
  _globals['_PREPAREPROPOSALRESPONSE']._serialized_end=6013
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_start=6015
  _globals['_PROCESSPROPOSALRESPONSE']._serialized_end=6097
  _globals['_EXTENDVOTERESPONSE']._serialized_start=6099
  _globals['_EXTENDVOTERESPONSE']._serialized_end=6169
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_start=6171
  _globals['_VERIFYVOTEEXTENSIONRESPONSE']._serialized_end=6261
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_start=6264
  _globals['_FINALIZEBLOCKRESPONSE']._serialized_end=6624
  _globals['_COMMITINFO']._serialized_start=6626
  _globals['_COMMITINFO']._serialized_end=6702
  _globals['_EXTENDEDCOMMITINFO']._serialized_start=6704
  _globals['_EXTENDEDCOMMITINFO']._serialized_end=6796
  _globals['_EVENT']._serialized_start=6798
  _globals['_EVENT']._serialized_end=6903
  _globals['_EVENTATTRIBUTE']._serialized_start=6905
  _globals['_EVENTATTRIBUTE']._serialized_end=6964
  _globals['_EXECTXRESULT']._serialized_start=6967
  _globals['_EXECTXRESULT']._serialized_end=7182
  _globals['_TXRESULT']._serialized_start=7184
  _globals['_TXRESULT']._serialized_end=7291
  _globals['_VALIDATOR']._serialized_start=7293
  _globals['_VALIDATOR']._serialized_end=7336
  _globals['_VALIDATORUPDATE']._serialized_start=7338
  _globals['_VALIDATORUPDATE']._serialized_end=7421
  _globals['_VOTEINFO']._serialized_start=7423
  _globals['_VOTEINFO']._serialized_end=7548
  _globals['_EXTENDEDVOTEINFO']._serialized_start=7551
  _globals['_EXTENDEDVOTEINFO']._serialized_end=7804
  _globals['_MISBEHAVIOR']._serialized_start=7807
  _globals['_MISBEHAVIOR']._serialized_end=8019
  _globals['_SNAPSHOT']._serialized_start=8021
  _globals['_SNAPSHOT']._serialized_end=8111
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.ganglion.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryIonByIonAddressRequest, QueryIonByIonAddressResponse,
    QueryIonByCreatorRequest, QueryIonByCreatorResponse,
    QueryGetValidatorsRequest, QueryGetValidatorsResponse,
    QueryIonsByInputSchemaHashRequest, QueryIonsByInputSchemaHashResponse,
    QueryGetPathwayRequest, QueryGetPathwayResponse,
    QueryListPathwaysRequest, QueryListPathwaysResponse,
    QueryListIonsByAddressesRequest, QueryListIonsByAddressesResponse,
    QueryUserPathwayStakeRequest, QueryUserPathwayStakeResponse,
    QueryGetUserRewardRequest, QueryGetUserRewardResponse,
    QueryGetProtocolFeeRequest, QueryGetProtocolFeeResponse,
    QueryPathwaysUsingIonRequest, QueryPathwaysUsingIonResponse,
    QueryIonsByReportsRequest, QueryIonsByReportsResponse,
    QueryListAllPathwaysRequest, QueryListAllPathwaysResponse,
    QueryGetRewardRequest, QueryGetRewardResponse,
    QueryGetStakeRequest, QueryGetStakeResponse,
    QueryGetIonRequest, QueryGetIonResponse,
    QueryGetPathwayUnstakeInitiatedUsersRequest, QueryGetPathwayUnstakeInitiatedUsersResponse,
    QueryGetStakerRewardRequest, QueryGetStakerRewardResponse,
    QueryGetAvailableIonsRequest, QueryGetAvailableIonsResponse, QueryGetAllowedIpsRequest, QueryGetAllowedIpsResponse
)

from neurionpy.protos.neurion.ganglion.tx_pb2 import (
    MsgUpdateParams, MsgUpdateParamsResponse,
    MsgRegisterIon, MsgRegisterIonResponse,
    MsgReportUnavailableIon, MsgReportUnavailableIonResponse,
    MsgUnreportUnavailableIon, MsgUnreportUnavailableIonResponse,
    MsgAddValidator, MsgAddValidatorResponse,
    MsgRemoveValidator, MsgRemoveValidatorResponse,
    MsgValidateAvailability, MsgValidateAvailabilityResponse,
    MsgRegisterPathway, MsgRegisterPathwayResponse,
    MsgStakePathway, MsgStakePathwayResponse,
    MsgRefundPathwayStake, MsgRefundPathwayStakeResponse,
    MsgInitUnstakePathway, MsgInitUnstakePathwayResponse,
    MsgClaimProtocolFee, MsgClaimProtocolFeeResponse,
    MsgSettlePathwayStake, MsgSettlePathwayStakeResponse,
    MsgStakeToGanglion, MsgStakeToGanglionResponse,
    MsgClaimReward, MsgClaimRewardResponse,
    MsgUnstakeFromGanglion, MsgUnstakeFromGanglionResponse,
    MsgUpdatePathway, MsgUpdatePathwayResponse, MsgRemoveIon, MsgRemovePathway
)

from neurionpy.synapse.tx_helpers import SubmittedTx


class GanglionQuery(ABC):
    """GanglionQuery defines the interface for querying the Ganglion module."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """Query the parameters of the Ganglion module."""

    @abstractmethod
    def IonByIonAddress(self, request: QueryIonByIonAddressRequest) -> QueryIonByIonAddressResponse:
        """Query an Ion by its ion_address."""

    @abstractmethod
    def IonByCreator(self, request: QueryIonByCreatorRequest) -> QueryIonByCreatorResponse:
        """Query an Ion by its creator."""

    @abstractmethod
    def GetValidators(self, request: QueryGetValidatorsRequest) -> QueryGetValidatorsResponse:
        """Query the list of validators."""

    @abstractmethod
    def IonsByInputSchemaHash(self, request: QueryIonsByInputSchemaHashRequest) -> QueryIonsByInputSchemaHashResponse:
        """Query Ions by input_schema_hash with pagination."""

    @abstractmethod
    def GetPathway(self, request: QueryGetPathwayRequest) -> QueryGetPathwayResponse:
        """Query a pathway by its ID."""

    @abstractmethod
    def ListPathways(self, request: QueryListPathwaysRequest) -> QueryListPathwaysResponse:
        """List pathways for a creator with pagination."""

    @abstractmethod
    def ListIonsByAddresses(self, request: QueryListIonsByAddressesRequest) -> QueryListIonsByAddressesResponse:
        """List Ions by a list of ion addresses."""

    @abstractmethod
    def UserPathwayStake(self, request: QueryUserPathwayStakeRequest) -> QueryUserPathwayStakeResponse:
        """Query pathway stake for a given pathway and user."""

    @abstractmethod
    def GetUserReward(self, request: QueryGetUserRewardRequest) -> QueryGetUserRewardResponse:
        """Query user reward."""

    @abstractmethod
    def GetProtocolFee(self, request: QueryGetProtocolFeeRequest) -> QueryGetProtocolFeeResponse:
        """Query the protocol fee."""

    @abstractmethod
    def PathwaysUsingIon(self, request: QueryPathwaysUsingIonRequest) -> QueryPathwaysUsingIonResponse:
        """Query pathways using a given ion."""

    @abstractmethod
    def ListAllPathways(self, request: QueryListAllPathwaysRequest) -> QueryListAllPathwaysResponse:
        """List all pathways with pagination."""

    @abstractmethod
    def GetReward(self, request: QueryGetRewardRequest) -> QueryGetRewardResponse:
        """Query reward for a given user."""

    @abstractmethod
    def GetStake(self, request: QueryGetStakeRequest) -> QueryGetStakeResponse:
        """Query stake for a given user."""

    @abstractmethod
    def GetIon(self, request: QueryGetIonRequest) -> QueryGetIonResponse:
        """Query an Ion by its ID."""

    @abstractmethod
    def GetPathwayUnstakeInitiatedUsers(self,
                                        request: QueryGetPathwayUnstakeInitiatedUsersRequest) -> QueryGetPathwayUnstakeInitiatedUsersResponse:
        """Query pathway unstake initiated users."""

    @abstractmethod
    def GetStakerReward(self, request: QueryGetStakerRewardRequest) -> QueryGetStakerRewardResponse:
        """Query staker reward."""

    @abstractmethod
    def GetAvailableIons(self, request: QueryGetAvailableIonsRequest) -> QueryGetAvailableIonsResponse:
        """Query available Ions with pagination."""

    @abstractmethod
    def IonsByReports(self, request: QueryIonsByReportsRequest) -> QueryIonsByReportsResponse:
        """Query ions by reports with pagination."""

    @abstractmethod
    def GetAllowedIps(self, request: QueryGetAllowedIpsRequest) -> QueryGetAllowedIpsResponse:
        """Get allowed IPs."""

class GanglionMessage(ABC):
    """GanglionMessage defines the interface for sending transactions to the Ganglion module."""

    @abstractmethod
    def UpdateParams(self, message: MsgUpdateParams, memo: Optional[str] = None,
                     gas_limit: Optional[int] = None) -> SubmittedTx:
        """Update module parameters."""

    @abstractmethod
    def RegisterIon(self, message: MsgRegisterIon, memo: Optional[str] = None,
                    gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register an Ion."""

    @abstractmethod
    def ReportUnavailableIon(self, message: MsgReportUnavailableIon, memo: Optional[str] = None,
                             gas_limit: Optional[int] = None) -> SubmittedTx:
        """Report an unavailable Ion."""

    @abstractmethod
    def UnreportUnavailableIon(self, message: MsgUnreportUnavailableIon, memo: Optional[str] = None,
                               gas_limit: Optional[int] = None) -> SubmittedTx:
        """Unreport an unavailable Ion."""

    @abstractmethod
    def AddValidator(self, message: MsgAddValidator, memo: Optional[str] = None,
                     gas_limit: Optional[int] = None) -> SubmittedTx:
        """Add a validator."""

    @abstractmethod
    def RemoveValidator(self, message: MsgRemoveValidator, memo: Optional[str] = None,
                        gas_limit: Optional[int] = None) -> SubmittedTx:
        """Remove a validator."""

    @abstractmethod
    def RegisterPathway(self, message: MsgRegisterPathway, memo: Optional[str] = None,
                        gas_limit: Optional[int] = None) -> SubmittedTx:
        """Register a pathway."""

    @abstractmethod
    def StakePathway(self, message: MsgStakePathway, memo: Optional[str] = None,
                     gas_limit: Optional[int] = None) -> SubmittedTx:
        """Stake tokens to a pathway."""

    @abstractmethod
    def RefundPathwayStake(self, message: MsgRefundPathwayStake, memo: Optional[str] = None,
                           gas_limit: Optional[int] = None) -> SubmittedTx:
        """Refund pathway stake."""

    @abstractmethod
    def StakeToGanglion(self, message: MsgStakeToGanglion, memo: Optional[str] = None,
                        gas_limit: Optional[int] = None) -> SubmittedTx:
        """Stake tokens to Ganglion."""

    @abstractmethod
    def ClaimReward(self, message: MsgClaimReward, memo: Optional[str] = None,
                    gas_limit: Optional[int] = None) -> SubmittedTx:
        """Claim reward."""

    @abstractmethod
    def UnstakeFromGanglion(self, message: MsgUnstakeFromGanglion, memo: Optional[str] = None,
                            gas_limit: Optional[int] = None) -> SubmittedTx:
        """Unstake tokens from Ganglion."""

    @abstractmethod
    def UpdatePathway(self, message: MsgUpdatePathway, memo: Optional[str] = None,
                      gas_limit: Optional[int] = None) -> SubmittedTx:
        """Update an existing pathway."""

    @abstractmethod
    def ValidateAvailability(self, message: MsgValidateAvailability, memo: Optional[str] = None,
                             gas_limit: Optional[int] = None) -> SubmittedTx:
        """Validate the availability of an Ion."""

    @abstractmethod
    def InitUnstakePathway(self, message: MsgInitUnstakePathway, memo: Optional[str] = None,
                           gas_limit: Optional[int] = None) -> SubmittedTx:
        """Initiate unstaking for a pathway."""

    @abstractmethod
    def ClaimProtocolFee(self, message: MsgClaimProtocolFee, memo: Optional[str] = None,
                         gas_limit: Optional[int] = None) -> SubmittedTx:
        """Claim the protocol fee."""

    @abstractmethod
    def SettlePathwayStake(self, message: MsgSettlePathwayStake, memo: Optional[str] = None,
                           gas_limit: Optional[int] = None) -> SubmittedTx:
        """Settle a pathway stake."""

    @abstractmethod
    def RemoveIon(self,message: MsgRemoveIon,memo: Optional[str] = None,gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Remove an Ion."""

    @abstractmethod
    def RemovePathway(
            self,
            message: MsgRemovePathway,
            memo: Optional[str] = None,
            gas_limit: Optional[int] = None,
    ) -> SubmittedTx:
        """Update an existing pathway."""


import base64
import json
from typing import Union

from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.common.utils import json_encode
from neurionpy.mint.interface import Mint
from neurionpy.protos.cosmos.mint.v1beta1.query_pb2 import (
    QueryAnnualProvisionsResponse,
    QueryInflationResponse,
    QueryParamsResponse,
)


def isNumber(value: Union[str, bytes]) -> bool:
    """
    Check is string ob bytes is number.

    :param value: str, bytes
    :return: bool
    """
    try:
        float(str(value))
        return True
    except ValueError:
        return False


class MintRestClient(Mint):
    """Mint REST client."""

    API_URL = "/cosmos/mint/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def AnnualProvisions(self) -> QueryAnnualProvisionsResponse:
        """
        AnnualProvisions current minting annual provisions value.

        :return: a QueryAnnualProvisionsResponse instance
        """
        json_response = self._rest_api.get(f"{self.API_URL}/annual_provisions")
        # The QueryAnnualProvisionsResponse expect a base64 encoded value
        # but the Rest endpoint return digits
        j = json.loads(json_response)
        if isNumber(j["annual_provisions"]):
            j["annual_provisions"] = base64.b64encode(
                j["annual_provisions"].encode()
            ).decode("utf8")
        json_response = json_encode(j).encode("utf-8")

        return Parse(json_response, QueryAnnualProvisionsResponse())

    def Inflation(self) -> QueryInflationResponse:
        """
        Inflation returns the current minting inflation value.

        :return: a QueryInflationResponse instance
        """
        json_response = self._rest_api.get(f"{self.API_URL}/inflation")
        # The QueryInflationResponse expect a base64 encoded value
        # but the Rest endpoint return digits
        j = json.loads(json_response)
        if isNumber(j["inflation"]):
            j["inflation"] = base64.b64encode(j["inflation"].encode()).decode("utf8")
        json_response = json_encode(j).encode("utf-8")

        return Parse(json_response, QueryInflationResponse())

    def Params(self) -> QueryParamsResponse:
        """
        Params queries params of the Mint module.

        :return: a QueryParamsResponse instance
        """
        json_response = self._rest_api.get(f"{self.API_URL}/params")
        return Parse(json_response, QueryParamsResponse())



from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.protos.cosmos.base.tendermint.v1beta1.query_pb2 import (
    GetBlockByHeightRequest,
    GetBlockByHeightResponse,
    GetLatestBlockRequest,
    GetLatestBlockResponse,
    GetLatestValidatorSetRequest,
    GetLatestValidatorSetResponse,
    GetNodeInfoRequest,
    GetNodeInfoResponse,
    GetSyncingRequest,
    GetSyncingResponse,
    GetValidatorSetByHeightRequest,
    GetValidatorSetByHeightResponse,
)
from neurionpy.tendermint.interface import CosmosBaseTendermint


class CosmosBaseTendermintRestClient(CosmosBaseTendermint):
    """Cosmos Base Tendermint REST client."""

    API_URL = "/cosmos/base/tendermint/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def GetNodeInfo(self, request: GetNodeInfoRequest) -> GetNodeInfoResponse:
        """
        GetNodeInfo queries the current node info.

        :param request: GetNodeInfoRequest
        :return: GetNodeInfoResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/node_info",
        )
        return Parse(json_response, GetNodeInfoResponse())

    def GetSyncing(self, request: GetSyncingRequest) -> GetSyncingResponse:
        """
        GetSyncing queries node syncing.

        :param request: GetSyncingRequest
        :return: GetSyncingResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/syncing",
        )
        return Parse(json_response, GetSyncingResponse())

    def GetLatestBlock(self, request: GetLatestBlockRequest) -> GetLatestBlockResponse:
        """
        GetLatestBlock returns the latest block.

        :param request: GetLatestBlockRequest
        :return: GetLatestBlockResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/blocks/latest",
        )
        return Parse(json_response, GetLatestBlockResponse())

    def GetBlockByHeight(
        self, request: GetBlockByHeightRequest
    ) -> GetBlockByHeightResponse:
        """
        GetBlockByHeight queries block for given height.

        :param request: GetBlockByHeightRequest
        :return: GetBlockByHeightResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/blocks/{request.height}")
        return Parse(json_response, GetBlockByHeightResponse())

    def GetLatestValidatorSet(
        self, request: GetLatestValidatorSetRequest
    ) -> GetLatestValidatorSetResponse:
        """
        GetLatestValidatorSet queries latest validator-set.

        :param request: GetLatestValidatorSetRequest
        :return: GetLatestValidatorSetResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validatorsets/latest", request
        )
        return Parse(json_response, GetLatestValidatorSetResponse())

    def GetValidatorSetByHeight(
        self, request: GetValidatorSetByHeightRequest
    ) -> GetValidatorSetByHeightResponse:
        """
        GetValidatorSetByHeight queries validator-set at a given height.

        :param request: GetValidatorSetByHeightRequest
        :return: GetValidatorSetByHeightResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/validatorsets/{request.height}", request
        )
        return Parse(json_response, GetValidatorSetByHeightResponse())



from cometbft.abci.v1 import types_pb2 as _types_pb2
from cometbft.types.v1 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetBlockResultsRequest(_message.Message):
    __slots__ = ("height",)
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int
    def __init__(self, height: _Optional[int] = ...) -> None: ...

class GetBlockResultsResponse(_message.Message):
    __slots__ = ("height", "tx_results", "finalize_block_events", "validator_updates", "consensus_param_updates", "app_hash")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TX_RESULTS_FIELD_NUMBER: _ClassVar[int]
    FINALIZE_BLOCK_EVENTS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_UPDATES_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: _ClassVar[int]
    APP_HASH_FIELD_NUMBER: _ClassVar[int]
    height: int
    tx_results: _containers.RepeatedCompositeFieldContainer[_types_pb2.ExecTxResult]
    finalize_block_events: _containers.RepeatedCompositeFieldContainer[_types_pb2.Event]
    validator_updates: _containers.RepeatedCompositeFieldContainer[_types_pb2.ValidatorUpdate]
    consensus_param_updates: _params_pb2.ConsensusParams
    app_hash: bytes
    def __init__(self, height: _Optional[int] = ..., tx_results: _Optional[_Iterable[_Union[_types_pb2.ExecTxResult, _Mapping]]] = ..., finalize_block_events: _Optional[_Iterable[_Union[_types_pb2.Event, _Mapping]]] = ..., validator_updates: _Optional[_Iterable[_Union[_types_pb2.ValidatorUpdate, _Mapping]]] = ..., consensus_param_updates: _Optional[_Union[_params_pb2.ConsensusParams, _Mapping]] = ..., app_hash: _Optional[bytes] = ...) -> None: ...



from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BaseAccount(_message.Message):
    __slots__ = ("address", "pub_key", "account_number", "sequence")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PUB_KEY_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    address: str
    pub_key: _any_pb2.Any
    account_number: int
    sequence: int
    def __init__(self, address: _Optional[str] = ..., pub_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., account_number: _Optional[int] = ..., sequence: _Optional[int] = ...) -> None: ...

class ModuleAccount(_message.Message):
    __slots__ = ("base_account", "name", "permissions")
    BASE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    base_account: BaseAccount
    name: str
    permissions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, base_account: _Optional[_Union[BaseAccount, _Mapping]] = ..., name: _Optional[str] = ..., permissions: _Optional[_Iterable[str]] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("max_memo_characters", "tx_sig_limit", "tx_size_cost_per_byte", "sig_verify_cost_ed25519", "sig_verify_cost_secp256k1")
    MAX_MEMO_CHARACTERS_FIELD_NUMBER: _ClassVar[int]
    TX_SIG_LIMIT_FIELD_NUMBER: _ClassVar[int]
    TX_SIZE_COST_PER_BYTE_FIELD_NUMBER: _ClassVar[int]
    SIG_VERIFY_COST_ED25519_FIELD_NUMBER: _ClassVar[int]
    SIG_VERIFY_COST_SECP256K1_FIELD_NUMBER: _ClassVar[int]
    max_memo_characters: int
    tx_sig_limit: int
    tx_size_cost_per_byte: int
    sig_verify_cost_ed25519: int
    sig_verify_cost_secp256k1: int
    def __init__(self, max_memo_characters: _Optional[int] = ..., tx_sig_limit: _Optional[int] = ..., tx_size_cost_per_byte: _Optional[int] = ..., sig_verify_cost_ed25519: _Optional[int] = ..., sig_verify_cost_secp256k1: _Optional[int] = ...) -> None: ...
